@@ -48,7 +48,7 @@ class ExcelRangeImportStepPerformer(StepPerformer):
 
         pandas_start_time = perf_counter()
 
-        sheet_index_to_df_name_and_range: Dict[int, Tuple[str, str]] = {}
+        sheet_index_to_df_range: Dict[int, str] = {}
         for range_import in range_imports:
             _range: Optional[str]
             if range_import['type'] == EXCEL_RANGE_IMPORT_TYPE_RANGE:
@@ -71,13 +71,13 @@ class ExcelRangeImportStepPerformer(StepPerformer):
                 df_name=final_df_name
             )
 
-            sheet_index_to_df_name_and_range[len(post_state.dfs) - 1] = (final_df_name, _range)
+            sheet_index_to_df_range[len(post_state.dfs) - 1] = _range
 
         pandas_processing_time = perf_counter() - pandas_start_time
 
         return post_state, {
             'pandas_processing_time': pandas_processing_time,
-            'sheet_index_to_df_name_and_range': sheet_index_to_df_name_and_range,
+            'new_sheet_index_to_df_range': sheet_index_to_df_range,
             'result': {
                 # TODO: fill in the result, when we make the frontend
             }
@@ -97,7 +97,7 @@ class ExcelRangeImportStepPerformer(StepPerformer):
                 post_state, 
                 get_param(params, 'file_path'),
                 get_param(params, 'sheet_name'),
-                (execution_data if execution_data is not None else dict()).get('sheet_index_to_df_name_and_range', {})
+                (execution_data if execution_data is not None else dict()).get('new_sheet_index_to_df_range', {})
             )
         ]
 
